@@ -1,10 +1,9 @@
-from abc import abstractmethod, ABCMeta
 import typing
+from abc import ABCMeta, abstractmethod
 
-from mlflow.entities import ViewType
+from mlflow.entities import Columns, Metric, RunLog, ViewType
 from mlflow.store.entities.paged_list import PagedList
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
-from mlflow.entities import Columns, Metric
 
 
 class AbstractStore:
@@ -68,7 +67,9 @@ class AbstractStore:
         """
         pass
 
-    def get_experiment_by_name(self, experiment_name, *args, **kwargs):
+    def get_experiment_by_name(
+        self, experiment_name, owner_subject_id: typing.Optional[str] = None
+    ):
         """
         Fetch the experiment by name from the backend store.
         This is a base implementation using ``list_experiments``, derived classes may have
@@ -335,3 +336,14 @@ class AbstractStore:
         self, run_id: str, metric_keys: typing.Iterator[str]
     ) -> typing.Dict[str, typing.List[Metric]]:
         raise NotImplementedError()
+
+    def insert_run_logs(self, run_uuid: str, run_logs: typing.List[RunLog]):
+        raise NotImplementedError()
+
+    def get_latest_run_log(self, run_uuid: str, key: str, log_type: str) -> RunLog:
+        raise NotImplementedError()
+
+    def list_run_logs(
+        self, run_uuid: str, key: typing.Optional[str], log_type: typing.Optional[str]
+    ) -> typing.List[RunLog]:
+        raise NotImplementedError()
