@@ -4,30 +4,38 @@ This is a lower level API than the :py:mod:`mlflow.tracking.fluent` module, and
 exposed in the :py:mod:`mlflow.tracking` module.
 """
 
+import os
 import time
 import typing
-import os
+from collections import OrderedDict
 
+from mlflow.entities import (
+    ExperimentTag,
+    Metric,
+    Param,
+    RunLog,
+    RunStatus,
+    RunTag,
+    ViewType,
+)
+from mlflow.exceptions import MlflowException
+from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE, ErrorCode
+from mlflow.store.artifact.artifact_repository_registry import get_artifact_repository
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
 from mlflow.tracking._tracking_service import utils
+from mlflow.utils.mlflow_tags import MLFLOW_USER
+from mlflow.utils.string_utils import is_string_type
+from mlflow.utils.uri import add_databricks_profile_info_to_artifact_uri
 from mlflow.utils.validation import (
-    _validate_param_name,
-    _validate_tag_name,
-    _validate_run_id,
+    PARAM_VALIDATION_MSG,
     _validate_experiment_artifact_location,
     _validate_experiment_name,
     _validate_metric,
     _validate_param_keys_unique,
-    PARAM_VALIDATION_MSG,
+    _validate_param_name,
+    _validate_run_id,
+    _validate_tag_name,
 )
-from mlflow.entities import Param, Metric, RunStatus, RunTag, ViewType, ExperimentTag
-from mlflow.exceptions import MlflowException
-from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE, ErrorCode
-from mlflow.store.artifact.artifact_repository_registry import get_artifact_repository
-from mlflow.utils.mlflow_tags import MLFLOW_USER
-from mlflow.utils.string_utils import is_string_type
-from mlflow.utils.uri import add_databricks_profile_info_to_artifact_uri
-from collections import OrderedDict
 
 
 class TrackingServiceClient:
@@ -454,3 +462,14 @@ class TrackingServiceClient:
             order_by=order_by,
             page_token=page_token,
         )
+
+    def insert_run_logs(self, run_uuid: str, run_logs: typing.List[RunLog]):
+        self.store.insert_run_logs(run_uuid=run_uuid, run_logs=run_logs)
+
+    def get_latest_run_log(self, run_uuid: str, key: str, log_type: str) -> RunLog:
+        return self.store.get_latest_run_log(run_uuid=run_uuid, key=key, log_type=log_type)
+
+    def list_run_logs(
+        self, run_uuid: str, key: typing.Optional[str] = None, log_type: typing.Optional[str] = None
+    ) -> typing.List[RunLog]:
+        return self.store.list_run_logs(run_uuid=run_uuid, key=key, log_type=log_type)
